pub struct IpcClient { /* private fields */ }Implementations
Sourceimpl IpcClient
impl IpcClient
pub fn new(socket_path: PathBuf) -> Self
Sourcepub async fn send(&self, request: Request) -> Result<Response>
pub async fn send(&self, request: Request) -> Result<Response>
Send a request to the daemon manager and return the response. Each call creates a fresh connection (simple request-response model).
Sourcepub async fn is_manager_running(&self) -> bool
pub async fn is_manager_running(&self) -> bool
Check if the daemon manager is reachable by sending a Ping.