pub struct IpcServer { /* private fields */ }Implementations
Sourceimpl IpcServer
impl IpcServer
pub fn new(socket_path: PathBuf) -> Self
Sourcepub async fn run<F, Fut>(
&self,
handler: Arc<F>,
shutdown_rx: Receiver<()>,
) -> Result<()>
pub async fn run<F, Fut>( &self, handler: Arc<F>, shutdown_rx: Receiver<()>, ) -> Result<()>
Run the IPC server, dispatching each request to the given handler.
The handler receives a Request and returns a Response. The server
keeps running until the handler returns a response indicating shutdown
or shutdown_rx fires.